@@ -24,10 +24,14 @@ from typing import (
     TYPE_CHECKING,
     List,
 )
+import logging
 
 if TYPE_CHECKING:
+
     from .tag import Tag
 
+log = logging.getLogger('Favorite')
+
 
 # pylint: disable=R
 class Favorite:
@@ -36,25 +40,25 @@ class Favorite:
     """
     def __init__(self, favorite_id: str):
         self.favorite_id = favorite_id
-        raise NotImplementedError
 
     def get_id(self):
         """
         get favorite_id
         :return:
         """
+        log.info('get_id() <%s>', self)
         return self.favorite_id
 
     async def tags(self) -> List[Tag]:
         """
         get favorite tags
         """
-        # TODO
+        # TODO -> favorite tags
         return []
 
-    async def find_all(self) -> List[Tag]:
+    async def find_all(self):
         """
         get all favorite tags
         """
-        # TODO
-        return []
+        # TODO -> find_all
+        return
